@@ -5,10 +5,11 @@
 """Classes to help developers avoid code duplication when writing tests for pyiron."""
 
 import unittest
-from os.path import dirname, abspath, join
+from os.path import split, join
 from os import remove
 from pyiron_base.project.generic import Project
 from abc import ABC
+from inspect import getfile
 
 __author__ = "Liam Huber"
 __copyright__ = (
@@ -24,14 +25,13 @@ __date__ = "Mar 23, 2021"
 
 class TestWithProject(unittest.TestCase, ABC):
     """
-    Tests that start and remove a project for their suite, and remove jobs from the project for each test.
+    Tests that start and remove a project for their suite.
     """
 
     @classmethod
     def setUpClass(cls):
-        cls.file_location = dirname(abspath(__file__)).replace("\\", "/")
-        cls.project_name = "test_project"
-        cls.project_path = join(cls.file_location, cls.project_name).replace("\\", "/")
+        cls.project_path = getfile(cls)[:-3].replace("\\", "/")
+        cls.file_location, cls.project_name = split(cls.project_path)
         cls.project = Project(cls.project_path)
 
     @classmethod
@@ -42,5 +42,11 @@ class TestWithProject(unittest.TestCase, ABC):
         except FileNotFoundError:
             pass
 
+
+class TestWithCleanProject(TestWithProject, ABC):
+    """
+    Tests that start and remove a project for their suite, and remove jobs from the project for each test.
+    """
+
     def tearDown(self):
         self.project.remove_jobs_silently(recursive=True)
