@@ -163,6 +163,9 @@ def wait_for_job(job, interval_in_s=5, max_iterations=100):
         job (pyiron_base.job.generic.GenericJob): Job to wait for
         interval_in_s (int): interval when the job status is queried from the database - default 5 sec.
         max_iterations (int): maximum number of iterations - default 100
+
+    Raises:
+        ValueError: max_iterations reached, job still running
     """
     if job.status.string not in job_status_finished_lst:
         if s.queue_adapter is not None and s.queue_adapter.remote_flag and job.server.queue is not None:
@@ -208,6 +211,9 @@ def wait_for_jobs(project, interval_in_s=5, max_iterations=100, recursive=True):
         interval_in_s (int): interval when the job status is queried from the database - default 5 sec.
         max_iterations (int): maximum number of iterations - default 100
         recursive (bool): search subprojects [True/False] - default=True
+
+    Raises:
+        ValueError: max_iterations reached, but jobs still running
     """
     finished = False
     for _ in range(max_iterations):
